[![codecov](https://codecov.io/gh/aviramha/aioaerospike/branch/master/graph/badge.svg)](https://codecov.io/gh/aviramha/aioaerospike)
[![Build Status](https://travis-ci.com/aviramha/aioaerospike.svg?branch=master)](https://travis-ci.com/aviramha/aioaerospike)

This library is planned to be an async API for Aerospike.
The library will be Pure-Python, Protocol based on the C Client.


** This package is 3rd party, unrelated to Aerospike company **

Licensed under MIT. See LICENSE
